#
# spec file for package perl-Params-Validate
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with opt

Name:           perl-Params-Validate
Version:        1.06
Release:        5.1
License:        Artistic-2.0
%define cpan_name Params-Validate
Summary:        Validate method/function parameters
Url:            http://search.cpan.org/dist/Params-Validate/
Group:          Development/Libraries/Perl
Source:         %{cpan_name}-%{version}.tar.gz
BuildRequires:  perl
BuildRequires:  perl(Module::Build)
BuildRequires:  perl-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1120
BuildRequires:  perl(Test::More) >= 0.88
%endif
%if %{with opt}
BuildRequires:  perl(Readonly::XS)
BuildRequires:  perl(Test::Taint) >= 0.02
%endif
BuildRequires:  perl(Attribute::Handlers) >= 0.79
BuildRequires:  perl(Module::Implementation)
BuildRequires:  perl(Scalar::Util) >= 1.10
BuildRequires:  perl(Test::Fatal)
Requires:       perl(Attribute::Handlers) >= 0.79
Requires:       perl(Module::Implementation)
Requires:       perl(Scalar::Util) >= 1.10
%{perl_requires}

%description
The Params::Validate module allows you to validate method or function
call parameters to an arbitrary level of specificity. At the simplest
level, it is capable of validating the required parameters were given
and that no unspecified additional parameters were passed in.

It is also capable of determining that a parameter is of a specific
type, that it is an object of a certain class hierarchy, that it
possesses certain methods, or applying validation callbacks to
arguments.

%prep
%setup -q -n %{cpan_name}-%{version}
%if 0%{?suse_version} <= 1120
  perl -p -i -e 's|0.3601|0.280801|' Build.PL
%endif

%build
perl Build.PL installdirs=vendor
./Build

%check
./Build test

%install
./Build install destdir=%{buildroot}
%perl_process_packlist
%perl_gen_filelist

%clean
rm -rf %{buildroot}

%files -f %{name}.files
%defattr(-, root, root)
%doc Changes LICENSE README

%changelog
* Mon Feb 13 2012 vcizek@suse.com
- update to 1.06
- Shut up warnings when XS is loaded on older 5.8.x Perl versions. Reported by
  Aaron James Trevena. RT #74742.
* Fri Feb 10 2012 vcizek@suse.com
- update to 1.05
  * The XS code had a code path where it could pass the contents of a Perl
    variable as the first argument to the XS croak() subroutine. This subroutine
    is like printf(), and should receive a format string as its first
    argument. According to RT #74777, this can lead to segfaults on some systems.
    This could in theory be a security bug, but it's very unlikely that
    untrusted user input could end up being passed to this croak(). It is called
    when a spec specifies a "depend" value on another parameter. The value of
    the "depend" parameter was passed in the first argument to croak().
  1.04    2012-02-08
  * Use the latest Module::XSOrPP dzil plugin to generate a saner Build.PL. No
    need update if you're using an earlier version.
  * This release uses Module::Implementation to handle loading the XS or pure
    Perl implementation of Params::Validate.
  1.02    2012-02-06
  * The previous release never loaded the XS implementation, even if it had been
    compiled.
  * With newer versions of Perl, the pure Perl implementation treated regexp
    objects differently than the XS implementation. They should be treated as
    belonging to the SCALARREF type for backwards compatibility.
  * These two bugs combined managed to break the test suites of a number of
    modules on CPAN. This release should fix them.
* Mon Feb  6 2012 vcizek@suse.com
- update to 1.01
- The generated Build.PL detects whether or not the machine it's run on has a
  working compiler, and disables XS automatically if it doesn't. Fixes RT
  [#44719].
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Fri Aug 26 2011 chris@computersalat.de
- remove Author from desc
- fix deps
  * fix build for 1120 (perl -p -i -e 's|0.3601|0.280801|' Build.PL)
- add bcond_with opt (Test::Taint, Readonly::XS)
* Mon Jun 13 2011 vcizek@novell.com
- update to 1.00
- Fix documentation indexing on search.cpan.org. Reported by Lutz Gehlen. RT
  [#68756].
* Mon May 30 2011 vcizek@novell.com
- update to 0.99
  - The metadata file - META.{json,yml} - had references to a different distro
    because of a copy and paste error. Reported by Bernhad Graf. RT #68514.
* Tue Apr 26 2011 vcizek@novell.com
- update to 0.98
- Attribute::Params::Validate's $VERSION regressed in 0.96.
  It's now manually set to 1.07.
* Thu Apr 21 2011 vcizek@novell.com
- update to 0.97
- The XS version of the code always called Carp::confess, regardless of
  whether you provided your own on_fail callback. Reported by Scott Bolte. RT
  [#66359].
- There were a couple spots that called eval without localizing $@ first. RT
  [#58087].
- The parameters for each key validation (can, isa, regex) are now checked,
  and an error is thrown if any of the keys are not valid. Basically, we
  validate the validation spec. Based on a patch by Andreas Faafeng. RT
  [#57831].
- This module now requires Perl 5.8.1.
- Switched to version 2.0 of the Artistic License.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sun Feb 21 2010 chris@computersalat.de
- update to 0.95
  - Skip t/29-taint-mode.t entirely, since it seems to randomly fail
    for people, despite already being marked a todo test.
- spec mods
  o sort TAGS
  o added cpan_name
  o fixed deps
  o added perl-macros
  - perl_gen_filelist
  o fixed Summary/Description
  o added Build test
* Mon Jan 25 2010 anicka@suse.cz
- update to 0.94
  * Removed the Makefile.PL entirely. If it was used then the XS
  code was never built, because I'm using the Module::Build XS
  layout.
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Thu Jun 19 2008 anicka@suse.cz
- update to 0.91
  * The fix for handling @_'s readonly-ness introduced a refcounting
  bug. One symptom of this was a failing Log::Dispatch test.
  * Make the XS version of Params::Validate recognize regexp objects
  with Perl 5.11.0-to-be.
  * With the XS version, when you passed @_ directly to validate() and
  then got a hash reference back, the values of that hash reference
  would be marked readonly.
* Thu Nov  1 2007 anicka@suse.cz
- update to 0.89
  * With validation turned off, the pure Perl version incorrectly
  ignored an odd number of parameters when a hash was expected (no
  validation still does the bare minimum of checks needed to set
  defaults).
  * Added pod & pod coverage tests.
  * Modernized test suite to use Test::More and fixed some test suite
  bugs along the way.
  * Attribute::Params::Validate would die when given a ValidatePos
  attribute containing one element.
  * More tests are skipped on 5.6.0.
* Thu Mar  8 2007 anicka@suse.cz
- update to 0.88
  * The XS version threw an error when it attempted to do "isa" or
    "can" validation on a value that was not a string or object,
    such as undef or a number.
* Thu Jan 25 2007 anicka@suse.cz
- update to 0.87
  * When determining the caller of a function in the XS version, use
    Perl's caller() function rather than CopSTASHPV. The caller()
    function apparently ignores the DB package, whereas the latter
    doesn't. This caused validate_options to be ignored when running
    under profiling (and probably the debugger as well).
* Thu Oct  5 2006 anicka@suse.cz
- update to 0.86
  * Only turn inlining on if __GNUC__ is defined
  * Removed spaces in #define, #ifdef, etc
  * If a type is specified as a string ('SCALAR', not SCALAR),
    this is now caught and a useful error is thrown.
* Fri Sep 29 2006 anicka@suse.cz
- update to 0.84
  * XS version uses Carp::confess instead of Carp::croak
  * bugfixes
  * speed optimalizations
- remove last patch (fixed in upstream)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 sf@suse.de
- update to 0.79
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Sun Jul 31 2005 cthiel@suse.de
- update to version 0.78
* Thu Jul  7 2005 pth@suse.de
- Update to 0.77
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 28 2003 ro@suse.de
- install to vendor location
* Tue Jul  1 2003 ro@suse.de
- use perl_process_packlist macro
* Sun Jun 22 2003 coolo@suse.de
- package directories
* Sun May 25 2003 ro@suse.de
- remove unpackaged files from buildroot
* Thu Mar 21 2002 sf@suse.de
-  initial versio 0.14
